==> quirc-0.9.83.tar.gz: quirc-0.9.83/generate_tags.cc <==
#include <stdio.h>
#include <strings.h>

int main() {
  int n, n2;
  printf("#ifdef DMALLOC\n");
  printf("#include <dmalloc.h>\n");
  printf("#endif\n");
  printf("\n");
  printf("#include \"tcltk.h\"\n");
  printf("extern void configuretags(char *pathname, char *font, char *boldfont) {\n");
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%d\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d)\",pathname,font);\n",n,n2,n,n2);
      //printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%d\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -font \\\"%%q\\\"\",pathname,font);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%db\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -font \\\"%%q\\\"\",pathname,boldfont);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%du\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -underline true\",pathname);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%dbu\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -underline true -font \\\"%%q\\\"\",pathname,boldfont);\n",n,n2,n,n2);
    }
  }
  printf("}\n");
  return 0;
}

==> quirc-0.9.84.tar.gz: quirc-0.9.84/generate_tags.cc <==
#include <stdio.h>
#include <strings.h>

int main() {
  int n, n2;
  printf("#ifdef DMALLOC\n");
  printf("#include <dmalloc.h>\n");
  printf("#endif\n");
  printf("\n");
  printf("#include \"tcltk.h\"\n");
  printf("extern void configuretags(const char *pathname, const char *font, const char *boldfont) {\n");
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%d\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d)\",pathname,font);\n",n,n2,n,n2);
      //printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%d\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -font \\\"%%q\\\"\",pathname,font);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%db\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -font \\\"%%q\\\"\",pathname,boldfont);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%du\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -underline true\",pathname);\n",n,n2,n,n2);
    }
  }
  for(n=0;n<16;n++) {
    for(n2=0;n2<16;n2++) {
      printf("  TT_EvalF(TT_ARGS,\"%%s tag configure \\\"%d,%dbu\\\" -foreground $::dynamic::theme_color(%d) -background $::dynamic::theme_color(%d) -underline true -font \\\"%%q\\\"\",pathname,boldfont);\n",n,n2,n,n2);
    }
  }
  printf("}\n");
  return 0;
}
